==> noahs-2.0.6.tar.gz: noahs/src/ModalForm.php <==
<?php 

	namespace Drupal\noahs_page_builder;
	use Drupal\noahs_page_builder\ControlBase;
	
   class ModalForm{


	// public function content_template();

	public static function render_form($fields, $values,  $delta = null, $parent = null) {

		$form = [];
		$tabs = array();

		$default_fields = new ControlBase;
		$groupFields = $default_fields->groupFields($fields);

		$tabs_class = new ControlsManager();
		
		$data_controls = $tabs_class->render_tabs($groupFields, $values);

		$form[] = $data_controls['form'];

		return $form;
	}

	public static function renderSubFields($fields, $values = null, $delta = null, $parent = null) {

		$form = [];
		// group by tabs
		$tabs = array();

		foreach ($fields as $key => $value) {


			if (isset($value['type']) && $value['type'] === 'tab') {

				$currentTab = $key;
				$tabs[$currentTab] = $value;
				$tabs[$currentTab]['items'] = [];
				// Agregar el título de la pestaña
				$tabs[$currentTab]['title'] = isset($value['title']) ? $value['title'] : $currentTab;
			} else {
				if (isset($value['tab'])) {
					$tabName = $value['tab'];
					$group = isset($value['group']) ? $value['group'] : null;
		
					// Verificar si hay grupos o no
					if ($group !== null) {
						$tabs[$tabName]['items'][$group]['title'] = isset($value['title']) ? $value['title'] : $group;
						$tabs[$tabName]['items'][$group][$key] = $value;
					} else {
						$tabs[$tabName]['items'][$key] = $value;
					}
				}
			}
		}

		$tabs_class = new ControlsManager();
	
		$data_controls = $tabs_class->render_tabs($tabs, $values, 'multiple', $delta, $parent);
	
		return $data_controls['form'];
	}

   }

==> noahs-2.0.7.tar.gz: noahs/src/ModalForm.php <==
<?php 

namespace Drupal\noahs_page_builder;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;
	
   class ModalForm{


	// public function content_template();

	public static function renderForm($fields, $values,  $delta = null, $parent = null) {
		$controlService = \Drupal::service('noahs_page_builder.control_service');
		$form = [];
		$tabs = array();

		$groupFields = $controlService->groupFields($fields);

		$tabs_class = new ControlsManager();
		
		$data_controls = $tabs_class->render_tabs($groupFields, $values);

		$form[] = $data_controls['form'];

		return $form;
	}

	public static function renderSubFields($fields, $values = null, $delta = null, $parent = null) {
		$form = [];

		// group by tabs
		$tabs = array();

		foreach ($fields as $key => $value) {


			if (isset($value['type']) && $value['type'] === 'tab') {

				$currentTab = $key;
				$tabs[$currentTab] = $value;
				$tabs[$currentTab]['items'] = [];
				// Agregar el título de la pestaña
				$tabs[$currentTab]['title'] = isset($value['title']) ? $value['title'] : $currentTab;
			} else {
				if (isset($value['tab'])) {
					$tabName = $value['tab'];
					$group = isset($value['group']) ? $value['group'] : null;
		
					// Verificar si hay grupos o no
					if ($group !== null) {
						$tabs[$tabName]['items'][$group]['title'] = isset($value['title']) ? $value['title'] : $group;
						$tabs[$tabName]['items'][$group][$key] = $value;
					} else {
						$tabs[$tabName]['items'][$key] = $value;
					}
				}
			}
		}

		$tabs_class = new ControlsManager();
	
		$data_controls = $tabs_class->render_tabs($tabs, $values, 'multiple', $delta, $parent);
	
		return $data_controls['form'];
	}

   }
